@@ -1,4 +1,4 @@
-def bubble_sort(arr: list):
+def bubble_sort(arr: list) -> list:
     # sourcery skip: remove-zero-from-range, use-itertools-product
     """Sort a list using bubble sort
 
@@ -13,8 +13,11 @@ def bubble_sort(arr: list):
     # Loop over the entire list
     for _ in range(1, size):
         # Loop over the list to swap the items
+        # Basically loop in pairs
         for j in range(0, size - 1):
             # Swap items if the current selected is greater than the next
             if arr[j] > arr[j + 1]:
                 # Swap
-                arr[j], arr[j + 1] = arr[j + 1], arr[j]
\ No newline at end of file
+                arr[j], arr[j + 1] = arr[j + 1], arr[j]
+    
+    return arr
\ No newline at end of file
