@@ -1,4 +1,4 @@
-def insertion_sort(arr: list):
+def insertion_sort(arr: list) -> list:
     """Sort a list using insertion sort
 
     Args:
@@ -25,4 +25,6 @@ def insertion_sort(arr: list):
             j -= 1
         
         # Set the key to the position before the sorted element
-        arr[j + 1] = key
\ No newline at end of file
+        arr[j + 1] = key
+    
+    return arr
\ No newline at end of file
