@@ -1,4 +1,4 @@
-def selection_sort(arr: list):
+def selection_sort(arr: list) -> list:
     """Sort a list using selection sort
 
     Args:
@@ -9,7 +9,7 @@ def selection_sort(arr: list):
     """
     size = len(arr)
 
-    # Loop over entire array
+    # Loop over entire array except the last element
     for j in range(size - 1):
         # Set the current minimum index to j
         iMin = j
@@ -23,4 +23,6 @@ def selection_sort(arr: list):
         # If they aren't the same
         # Swap the minimum and the first element in the unsorted array
         if iMin != j:
-            arr[j], arr[iMin] = arr[iMin], arr[j]
\ No newline at end of file
+            arr[j], arr[iMin] = arr[iMin], arr[j]
+    
+    return arr
\ No newline at end of file
